==> ejc-techmanagement-impl-3.0.0-20250408.015501-89-sources.jar: com/ejianc/business/techmanagement/bean/DesignChangeEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_tec_design_change")
public class DesignChangeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="secondary_units")
    private String secondaryUnits; // 二级单位
    @TableField(value="change_name")
    private String changeName; // 变更名称
    @TableField(value="change_time")
    private Date changeTime; // 变更日期
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="drawing_id")
    private Long drawingId; // 图纸ID
    @TableField(value="drawing_name")
    private String drawingName; // 图纸名称
    @TableField(value="drawing_code")
    private String drawingCode; // 图纸编码
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="operator_code")
    private String operatorCode; // 经办人编码
    @TableField(value="operating_department")
    private String operatingDepartment; // 经办部门
    @TableField(value="change_content")
    private String changeContent; // 变更内容说明
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="disclosure_state")
    private Integer disclosureState; // 交底状态
    @TableField(value="disclosure_time")
    private Date disclosureTime; // 交底日期
    @TableField(value="disclosure_content")
    private String disclosureContent; // 交底内容及结果说明
    @TableField(value="org_id")

    private Long orgId; // 组织ID

    @TableField(value="org_name")
    private String orgName; // 组织名称

    @TableField(value="org_code")
    private String orgCode; // 组织编码

    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型
    @TableField(value="measure_type")
    private String measureType; // 工程度量方式
    @TableField(value="measure_value")
    private String measureValue; // 度量值
    @TableField(value="disclosure_id")
    private Long disclosureId; // 交底ID
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父组织ID
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父组织编码

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }


    public String getEngineeringType() {
        return engineeringType;
    }

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }

    public String getMeasureType() {
        return measureType;
    }

    public void setMeasureType(String measureType) {
        this.measureType = measureType;
    }

    public String getMeasureValue() {
        return measureValue;
    }

    public void setMeasureValue(String measureValue) {
        this.measureValue = measureValue;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getSecondaryUnits() {
        return secondaryUnits;
    }

    public void setSecondaryUnits(String secondaryUnits) {
        this.secondaryUnits = secondaryUnits;
    }
    public String getChangeName() {
        return changeName;
    }

    public void setChangeName(String changeName) {
        this.changeName = changeName;
    }
    public Date getChangeTime() {
        return changeTime;
    }

    public void setChangeTime(Date changeTime) {
        this.changeTime = changeTime;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getDrawingId() {
        return drawingId;
    }

    public void setDrawingId(Long drawingId) {
        this.drawingId = drawingId;
    }
    public String getDrawingName() {
        return drawingName;
    }

    public void setDrawingName(String drawingName) {
        this.drawingName = drawingName;
    }
    public String getDrawingCode() {
        return drawingCode;
    }

    public void setDrawingCode(String drawingCode) {
        this.drawingCode = drawingCode;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getOperatingDepartment() {
        return operatingDepartment;
    }

    public void setOperatingDepartment(String operatingDepartment) {
        this.operatingDepartment = operatingDepartment;
    }
    public String getChangeContent() {
        return changeContent;
    }

    public void setChangeContent(String changeContent) {
        this.changeContent = changeContent;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getDisclosureState() {
        return disclosureState;
    }

    public void setDisclosureState(Integer disclosureState) {
        this.disclosureState = disclosureState;
    }
    public Date getDisclosureTime() {
        return disclosureTime;
    }

    public void setDisclosureTime(Date disclosureTime) {
        this.disclosureTime = disclosureTime;
    }
    public String getDisclosureContent() {
        return disclosureContent;
    }

    public void setDisclosureContent(String disclosureContent) {
        this.disclosureContent = disclosureContent;
    }
    
}

==> ejc-techmanagement-impl-3.0.0-20251127.061515-111-sources.jar: com/ejianc/business/techmanagement/bean/DesignChangeEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_tec_design_change")
public class DesignChangeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="secondary_units")
    private String secondaryUnits; // 二级单位
    @TableField(value="change_name")
    private String changeName; // 变更名称
    @TableField(value="change_time")
    private Date changeTime; // 变更日期
    @TableField(value="change_type")
    private Integer changeType; // 变更类型
    @TableField(value="drawing_id")
    private Long drawingId; // 图纸ID
    @TableField(value="drawing_name")
    private String drawingName; // 图纸名称
    @TableField(value="drawing_code")
    private String drawingCode; // 图纸编码
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="operator_code")
    private String operatorCode; // 经办人编码
    @TableField(value="operating_department")
    private String operatingDepartment; // 经办部门
    @TableField(value="change_content")
    private String changeContent; // 变更内容说明
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="disclosure_state")
    private Integer disclosureState; // 交底状态
    @TableField(value="disclosure_time")
    private Date disclosureTime; // 交底日期
    @TableField(value="disclosure_content")
    private String disclosureContent; // 交底内容及结果说明
    @TableField(value="org_id")

    private Long orgId; // 组织ID

    @TableField(value="org_name")
    private String orgName; // 组织名称

    @TableField(value="org_code")
    private String orgCode; // 组织编码

    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型
    @TableField(value="measure_type")
    private String measureType; // 工程度量方式
    @TableField(value="measure_value")
    private String measureValue; // 度量值
    @TableField(value="disclosure_id")
    private Long disclosureId; // 交底ID
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父组织ID
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父组织编码
    @TableField(value="disclosure_code")
    private String disclosureCode; // 交底单编码

    public String getDisclosureCode() {
        return disclosureCode;
    }

    public void setDisclosureCode(String disclosureCode) {
        this.disclosureCode = disclosureCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }


    public String getEngineeringType() {
        return engineeringType;
    }

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }

    public String getMeasureType() {
        return measureType;
    }

    public void setMeasureType(String measureType) {
        this.measureType = measureType;
    }

    public String getMeasureValue() {
        return measureValue;
    }

    public void setMeasureValue(String measureValue) {
        this.measureValue = measureValue;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getSecondaryUnits() {
        return secondaryUnits;
    }

    public void setSecondaryUnits(String secondaryUnits) {
        this.secondaryUnits = secondaryUnits;
    }
    public String getChangeName() {
        return changeName;
    }

    public void setChangeName(String changeName) {
        this.changeName = changeName;
    }
    public Date getChangeTime() {
        return changeTime;
    }

    public void setChangeTime(Date changeTime) {
        this.changeTime = changeTime;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getDrawingId() {
        return drawingId;
    }

    public void setDrawingId(Long drawingId) {
        this.drawingId = drawingId;
    }
    public String getDrawingName() {
        return drawingName;
    }

    public void setDrawingName(String drawingName) {
        this.drawingName = drawingName;
    }
    public String getDrawingCode() {
        return drawingCode;
    }

    public void setDrawingCode(String drawingCode) {
        this.drawingCode = drawingCode;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getOperatingDepartment() {
        return operatingDepartment;
    }

    public void setOperatingDepartment(String operatingDepartment) {
        this.operatingDepartment = operatingDepartment;
    }
    public String getChangeContent() {
        return changeContent;
    }

    public void setChangeContent(String changeContent) {
        this.changeContent = changeContent;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getDisclosureState() {
        return disclosureState;
    }

    public void setDisclosureState(Integer disclosureState) {
        this.disclosureState = disclosureState;
    }
    public Date getDisclosureTime() {
        return disclosureTime;
    }

    public void setDisclosureTime(Date disclosureTime) {
        this.disclosureTime = disclosureTime;
    }
    public String getDisclosureContent() {
        return disclosureContent;
    }

    public void setDisclosureContent(String disclosureContent) {
        this.disclosureContent = disclosureContent;
    }
    
}
